@@ -754,7 +754,7 @@ void cre_align_menu(SEA_VIEW *view)
   alignitems[clustalopt + MAX_MSA_ALGOS].label(strdup(options));
   alignitems[clustalopt + MAX_MSA_ALGOS].flags = attr;
   if (view->alignment_algorithm < 2) alignitems[clustalopt + MAX_MSA_ALGOS + 3].flags = FL_MENU_INACTIVE;
-  delete options;
+  delete[] options;
   view->menu_align = alignitems;
   view->menubar->add("Align", 0, NULL, (void*)view->menu_align, FL_SUBMENU_POINTER);
   if (view->count_msa_algos >= MAX_MSA_ALGOS) (alignitems + clustalopt + MAX_MSA_ALGOS + 2)->deactivate();
