@@ -5,6 +5,9 @@
 #include <FL/x.H>
 #include <FL/Fl_Sys_Menu_Bar.H>
 #include <FL/Fl_Help_View.H>
+#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
+#include <src/drivers/Quartz/Fl_Quartz_Graphics_Driver.H>
+#endif
 #include <FL/filename.H>
 #include <FL/fl_draw.H>
 #include <sys/stat.h>
