@@ -2,6 +2,9 @@
 #define PDF_OR_PS_H
 
 #include <FL/Fl_Paged_Device.H>
+#if 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION + FL_PATCH_VERSION >= 140
+#include <FL/Fl_Graphics_Driver.H>
+#endif
 
 #if !(defined(__APPLE__) || defined(WIN32)) && 100*FL_MAJOR_VERSION + 10*FL_MINOR_VERSION  + FL_PATCH_VERSION == 130
 // for X11 under 1.3.0 only
@@ -88,6 +91,34 @@ public:
   int height() ;
   int descent() ;
   friend class Fl_PDF_File_Device;
+  
+#if SEAVIEW_FLTK_VERSION >= 140
+  virtual void point(int x, int y) {}
+  virtual void line(int x, int y, int x1, int y1, int x2, int y2) {}
+  virtual void xyline(int x, int y, int x1, int y2, int x3) {}
+  virtual void yxline(int x, int y, int y1, int x2, int y3) {}
+  virtual void loop(int x0, int y0, int x1, int y1, int x2, int y2) {}
+  virtual void loop(int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3) {}
+  virtual void polygon(int x0, int y0, int x1, int y1, int x2, int y2) {}
+  virtual void polygon(int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3) {}
+  virtual int clip_box(int x, int y, int w, int h, int &X, int &Y, int &W, int &H) {return 0;}
+  virtual int not_clipped(int x, int y, int w, int h) {return 0;}
+  virtual void push_no_clip() {}
+  virtual void begin_complex_polygon() {}
+  virtual void transformed_vertex(double xf, double yf) {}
+  virtual void vertex(double x, double y) {}
+  virtual void end_points() {}
+  virtual void end_line() {}
+  virtual void end_loop() {}
+  virtual void end_polygon() {}
+  virtual void end_complex_polygon() {}
+  virtual void gap() {}
+  virtual void circle(double x, double y, double r) {}
+  virtual void arc(int x, int y, int w, int h, double a1, double a2) {}
+  virtual void pie(int x, int y, int w, int h, double a1, double a2) {}
+  virtual Fl_Bitmask create_bitmask(int w, int h, const uchar *array) {return 0;}
+  virtual void delete_bitmask(Fl_Bitmask bm) {}
+#endif
 };
 
 class Fl_PDF_File_Device : public Fl_Paged_Device
@@ -124,6 +155,7 @@ typedef Fl_PDF_File_Device Fl_PDF_or_PS_File_Device;
 
 #if defined(__APPLE__)
 #include <ApplicationServices/ApplicationServices.h>
+#undef check
 #if  (!__LP64__) && MAC_OS_X_VERSION_MAX_ALLOWED < 1070
 #define USE_PICT
 #endif
