@@ -204,7 +204,8 @@ typedef struct _SEA_VIEW {
 		  0: normal; 
 		  >= 1: 1 seul seq ecrite */
   int mod_cursor; /* FALSE: cursor ancien ignore; TRUE: ancien efface */
-  int char_width, line_height; /* taille en pixels des caracteres */
+  float char_width; /* largeur en pixels des caracteres */
+  int line_height; /* hauteur en pixels des lignes */
   int cursor_seq, cursor_site; /* position courante du curseur */
   int old_cursor_seq, old_cursor_site; /* position precedente du curseur*/
   int tot_sel_seqs; /* nbre courant de seqs selectionnees */
