@@ -12,6 +12,9 @@
 #include <FL/Fl_Value_Slider.H>
 #include <FL/Fl.H>
 #include <FL/fl_ask.H>
+#ifdef __APPLE__
+#include <FL/x.H> // for fl_mac_os_version
+#endif
 
 extern "C" {
 #include "phyml_util.h"
@@ -1123,6 +1126,7 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
   else if(nni_spr_b->value()) strcat(args, " -s BEST");
   if(!u_optimize->value()) { strcat(args, " -o lr"); user_tree = TRUE; }
   if (u_quiet->value()) strcat(args, " --quiet");
+  else                  strcat(args, " --no_memory_check");
   if(u_menutree->value()) {
 	   char *tree = view->trees[u_choice->value()];
 	   if(*tree == '[' && (p = strchr(tree, ']')) != NULL) { //remove tree header
@@ -1157,6 +1161,10 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
     sprintf(input, "%s.phy_phyml_stat.txt", base_fname);
     in = fopen(input, "r");
     }
+  if (in == NULL) {
+    sprintf(input, "%s.phy_phyml_stats", base_fname);
+    in = fopen(input, "r");
+    }
   logL = 0;
   if(in != NULL) {//search tree likelihood
 	  while(TRUE) {
@@ -1170,6 +1178,10 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
 	  }
   sprintf(input, "%s.phy_phyml_tree.txt", base_fname);
   in = fopen(input, "r");
+  if (in == NULL) {
+    sprintf(input, "%s.phy_phyml_tree", base_fname);
+    in = fopen(input, "r");
+    }
   if( status != 0 || in == NULL ) {
 	  if(in != NULL) fclose(in);
 	  if (is_view_valid(view)) fl_message("%s: tree building cancelled", extract_filename(view->masename));
@@ -1192,6 +1204,10 @@ void run_phyml_callback(Fl_Widget *ob, void *data)
     if (replicates > 0 && b_keep_trees->value()) {
       sprintf(input, "%s.phy_phyml_boot_trees.txt", base_fname);
       in = fopen(input, "r");
+      if (!in) {
+      	sprintf(input, "%s.phy_phyml_boot_trees", base_fname);
+      	in = fopen(input, "r");
+      }
       if (in) {
         FILE *out = NULL;
         sprintf(input, "%s.phy_phyml_boot_trees_truename.txt", base_fname);
