@@ -78,6 +78,7 @@ extern void replace_with_new_tree(FD_nj_plot *fd_nj_plot, char *newtree);
 /* globals */
 static int nextotu, num_noeud;
 extern Fl_Paged_Device::Page_Format printout_pageformat;
+extern Fl_Paged_Device::Page_Layout printout_layout;
 
 
 void rooted_unrooted_callback(Fl_Widget *o, void *data)
@@ -212,6 +213,7 @@ void squared2circular(FD_nj_plot *fd_nj_plot, Fl_Choice *o)
 	fd_unrooted->current_font = fd_nj_plot->font_family;
 	fd_unrooted->font_size = fd_nj_plot->font_size;
 	fd_nj_plot->fd_unrooted = (void *)fd_unrooted;
+  fd_nj_plot->leaf_trimmer->process_unrooted();
 }
 
 void circular2squared(FD_nj_plot *fd_nj_plot)
@@ -434,9 +436,9 @@ void print_unrooted(FD_unrooted *fd_unrooted, const char *name, bool to_ps_file,
   if (to_ps_file) {
     myprinter = (Fl_Printer*)new Fl_PDF_or_PS_File_Device();
     if (directname) 
-      error = ((Fl_PDF_or_PS_File_Device*)myprinter)->begin_document(directname, printout_pageformat);
+      error = ((Fl_PDF_or_PS_File_Device*)myprinter)->begin_document(directname, printout_pageformat, printout_layout);
     else
-      error = ((Fl_PDF_or_PS_File_Device*)myprinter)->start_job(name, printout_pageformat) ;
+      error = ((Fl_PDF_or_PS_File_Device*)myprinter)->start_job(name, printout_pageformat, printout_layout) ;
     if (error) return;
     }
   else {
@@ -694,18 +696,22 @@ return *ascend + *descend ;
 
 void free_unrooted(FD_unrooted *data)
 {
-	int i;
-	if(data->notu == 0) return;
-	/* de-allocate all memory */
-	for(i=0; i<2*data->notu - 1; i++) {
-		if(data->tabtax[i]->nom != NULL) free(data->tabtax[i]->nom);
-		free(data->tabtax[i]);
-	}
-	free(data->tabtax);
-	if(data->branche_noeuds != NULL) free(data->branche_noeuds);
-	if(data->branches != NULL) free(data->branches);
-	data->notu = 0;
-	free(data);
+  int i;
+  if(data->notu == 0) return;
+  /* de-allocate all memory */
+  for(i=0; i<2*data->notu - 1; i++) {
+    if(data->tabtax[i]->nom != NULL) free(data->tabtax[i]->nom);
+    free(data->tabtax[i]);
+  }
+  free(data->tabtax);
+  if(data->branche_noeuds != NULL) free(data->branche_noeuds);
+  for (i = 0; i < 2*data->notu - 3; i++) {
+    char *p = (data->branches+i)->nom;
+    if (p) free(p);
+  }
+  if(data->branches != NULL) free(data->branches);
+  data->notu = 0;
+  free(data);
 }
 
 
@@ -967,6 +973,7 @@ bignoeud *cre_new_tree(struct noeud *debut, struct noeud *parent, bignoeud *bigp
 	nouveau->l2 = debut->l2;
 	nouveau->l3 = debut->l3;
 	nouveau->nom = debut->nom;
+  nouveau->rank = debut->rank;
 	return nouveau;
 }
 
@@ -1186,9 +1193,10 @@ unrooted_branch *calc_position_noeuds(bignoeud *debut, bignoeud *parent,
 
 void mem_line(cp_point *debut, cp_point *fin, bignoeud *noeud_term, unrooted_branch *br)
 {
-	br->debut = *debut;
-	br->fin = *fin;
-	br->nom = noeud_term->nom;
+  br->debut = *debut;
+  br->fin = *fin;
+  br->rank = noeud_term->rank;
+  br->nom = noeud_term->nom ? strdup(noeud_term->nom) : NULL;
 }
 
 
